Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(503)

Unified Diff: runtime/include/dart_api.h

Issue 9332007: Spelling corrections to the API header file (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index a15481f02c8c31d9baf7bc2a545747c74ddf9931..edac66ea97950fdf65071d32004dd1d74885db29 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -1447,11 +1447,11 @@ struct Dart_CObject {
/**
* Posts a message on some port. The message will contain the
* Dart_CObject object graph rooted in the provided Dart_CObject.
*
* While the message is being sent the state of the graph of
- * Dart_CObject structures rooted in message should not be accessed,
- * as the message generation will make temporaly modification to the
+ * Dart_CObject structures rooted in 'message' should not be accessed,
+ * as the message generation will make temporary modifications to the
* data. When the message has been sent the graph will be fully
* restored.
*
@@ -1460,6 +1460,6 @@ struct Dart_CObject {
*
* \return True if the message was posted.
*/
-DART_EXPORT bool Dart_PostCObject(Dart_Port port_id, Dart_CObject* root);
+DART_EXPORT bool Dart_PostCObject(Dart_Port port_id, Dart_CObject* message);
#endif // INCLUDE_DART_API_H_
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
@@ -1447,11 +1447,11 @@ struct Dart_CObject {
/**
* Posts a message on some port. The message will contain the
- * Dart_CObject object graph rooted in the provided Dart_CObject.
+ * Dart_CObject object graph rooted in 'message'.
*
* While the message is being sent the state of the graph of

Powered by Google App Engine
This is Rietveld 408576698